nros_rmw_cffi_registered_names

Function nros_rmw_cffi_registered_names 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn nros_rmw_cffi_registered_names( buf: *mut *const c_char, cap: usize, ) -> usize
Diagnostic helper — fills buf with pointers to up to cap registered backend names. Returns the number of names available (may exceed cap). Pointer-valid for the program’s lifetime.

Safety

  • buf must either be NULL (when cap == 0) or point at writable memory of at least cap * sizeof(*const c_char) bytes.